pub unsafe fn statify<T>(r: &T) -> &'static TExpand description
Make the lifetime of a reference static. Be very careful with your reasoning why your usage doesn’t introduce UB!
pub unsafe fn statify<T>(r: &T) -> &'static TMake the lifetime of a reference static. Be very careful with your reasoning why your usage doesn’t introduce UB!